﻿
using System.Windows;
using System.Json;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Json;
using System.ServiceModel;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Browser;
using System.Net;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;


namespace NewYorkTimesTestJSON
{
	public partial class BasicPresidentialLayout : UserControl
	{
        private WebClient downloader;

        private ObservableCollection<CandidateDataHelper> candidates;
        private ObservableCollection<Ellipse> candidateCircles;
        private ObservableCollection<TextBlock> candidateNumbers;
        private ObservableCollection<Storyboard> candidateStoryboard;
        private ObservableCollection<SplineDoubleKeyFrame> candidateWidths;
        private ObservableCollection<SplineDoubleKeyFrame> candidateHeights;

        private int lastTimelineValue;
        private bool dataGathered;

        public BasicPresidentialLayout()
		{
			// Required to initialize variables
			InitializeComponent();

            dataGathered = false;
            candidates = new ObservableCollection<CandidateDataHelper>();            
            downloader = new WebClient();
            downloader.OpenReadCompleted += new OpenReadCompletedEventHandler(downloader_OpenReadCompleted);

            lastTimelineValue = 0;
            
		}


        void Page_Loaded(object sender, RoutedEventArgs e)
        {
            

            Uri dataURI = new Uri("http://www.designerandroid.com/myJSONData/CandData.json");
            downloader.OpenReadAsync(dataURI);
        }

        void downloader_OpenReadCompleted(object sender, OpenReadCompletedEventArgs e)
        {
            var result = e.Result;
            JsonObject candidateResult = (JsonObject)JsonObject.Load(result);
            
            if (candidateResult["CandidateDataTest"] == "true")
            {
                JsonArray CandidateList = (JsonArray)candidateResult["results"];
                foreach (JsonObject jsonOb in CandidateList)
                {
                    // Create data helper and add name
                    CandidateDataHelper tempCandidate = new CandidateDataHelper();
                    tempCandidate.CandidateName = jsonOb["CandidateName"];

                    // Create the list of weekData objects
                    List<WeekData> newsInformation = new List<WeekData>();

                    JsonArray specificData = (JsonArray)jsonOb["DatedData"];
                    foreach (JsonObject specificJson in specificData)
                    {
                        WeekData weekDataHolder = new WeekData();
                        string countBuffer = specificJson["articleCount"];
                        
                        weekDataHolder.Count = Convert.ToInt32(countBuffer);
                        weekDataHolder.FormatRawDate(specificJson["dateRange"]);

                        newsInformation.Add(weekDataHolder);
                    }

                    // Add the list to the data helper
                    tempCandidate.DatedData = newsInformation;

                    candidates.Add(tempCandidate);
                    
                }
            }
            //testBox.ItemsSource = candidates;
            //testCounter.Text = candidates[1].DatedData.Count.ToString();
            gatherCircles();
            updateAllData(0);
            dataGathered = true;
        }

        private void updateAllData(int placement)
        {

            for (int i = 0; i < candidates.Count; i++)
            {
                //candidateCircles[i].Width = candidateCircles[i].Height = 1.5 * candidates[i].DatedData[placement].Count;
                candidateWidths[i].Value = candidateHeights[i].Value = 20 * Math.Sqrt(candidates[i].DatedData[placement].Count);


                candidateNumbers[i].Text = candidates[i].DatedData[placement].Count.ToString();
                candidateStoryboard[i].Begin();
            }

            WeekDisplay.Text = candidates[0].DatedData[placement].StartDate.ToShortDateString() + " - " + candidates[0].DatedData[placement].EndDate.ToShortDateString();

            switch (placement)
            {
                case 6:
                    _6Entrance.Begin();
                    break;
                case 9:
                    _9Entrance.Begin();
                    break;
                case 12:
                    _12Entrance.Begin();
                    break;
                case 23:
                    _23Entrance.Begin();
                    break;
                case 59:
                    _54Entrance.Begin();
                    break;
                case 64:
                    _64Entrance.Begin();
                    break;
                case 68:
                    _68Entrance.Begin();
                    break;
                case 81:
                    _81Entrance.Begin();
                    break;
                case 93:
                    _93Entrance.Begin();
                    break;
                case 94:
                    _94Entrance.Begin();
                    break;
                case 104:
                    PlayBtn.Visibility = Visibility.Visible;
                    break;
                default:
                    break;
            }
            
        }

        void gatherCircles()
        {
            candidateCircles = new ObservableCollection<Ellipse>();
            candidateCircles.Add(McCainCircle);
            candidateCircles.Add(RichardsonCircle);
            candidateCircles.Add(KucinichCircle);
            candidateCircles.Add(GravelCircle);
            candidateCircles.Add(EdwardsCircle);
            candidateCircles.Add(DoddCircle);
            candidateCircles.Add(ClintonCircle);
            candidateCircles.Add(BidenCircle);
            candidateCircles.Add(ObamaCircle);
            candidateCircles.Add(ThompsonCircle);
            candidateCircles.Add(RomneyCircle);
            candidateCircles.Add(PaulCircle);
            candidateCircles.Add(HunterCircle);
            candidateCircles.Add(HuckabeeCircle);
            candidateCircles.Add(GiulianiCircle);

            candidateNumbers = new ObservableCollection<TextBlock>();
            candidateNumbers.Add(McCainCount);
            candidateNumbers.Add(RichardsonCount);
            candidateNumbers.Add(KucinichCount);
            candidateNumbers.Add(GravelCount);
            candidateNumbers.Add(EdwardsCount);
            candidateNumbers.Add(DoddCount);
            candidateNumbers.Add(ClintonCount);
            candidateNumbers.Add(BidenCount);
            candidateNumbers.Add(ObamaCount);
            candidateNumbers.Add(ThompsonCount);
            candidateNumbers.Add(RomneyCount);
            candidateNumbers.Add(PaulCount);
            candidateNumbers.Add(HunterCount);
            candidateNumbers.Add(HuckabeeCount);
            candidateNumbers.Add(GiulianiCount);

            candidateStoryboard = new ObservableCollection<Storyboard>();
            candidateStoryboard.Add(McCainStoryboard);
            candidateStoryboard.Add(RichardsonStoryboard);
            candidateStoryboard.Add(KucinichStoryboard);
            candidateStoryboard.Add(GravelStoryboard);
            candidateStoryboard.Add(EdwardsStoryboard);
            candidateStoryboard.Add(DoddStoryboard);
            candidateStoryboard.Add(ClintonStoryboard);
            candidateStoryboard.Add(BidenStoryboard);
            candidateStoryboard.Add(ObamaStoryboard);
            candidateStoryboard.Add(ThompsonStoryboard);
            candidateStoryboard.Add(RomneyStoryboard);
            candidateStoryboard.Add(PaulStoryboard);
            candidateStoryboard.Add(HunterStoryboard);
            candidateStoryboard.Add(HuckabeeStoryboard);
            candidateStoryboard.Add(GiulianiStoryboard);

            candidateWidths = new ObservableCollection<SplineDoubleKeyFrame>();
            candidateWidths.Add(McCainWidth);
            candidateWidths.Add(RichardsonWidth);
            candidateWidths.Add(KucinichWidth);
            candidateWidths.Add(GravelWidth);
            candidateWidths.Add(EdwardsWidth);
            candidateWidths.Add(DoddWidth);
            candidateWidths.Add(ClintonWidth);
            candidateWidths.Add(BidenWidth);
            candidateWidths.Add(ObamaWidth);
            candidateWidths.Add(ThompsonWidth);
            candidateWidths.Add(RomneyWidth);
            candidateWidths.Add(PaulWidth);
            candidateWidths.Add(HunterWidth);
            candidateWidths.Add(HuckabeeWidth);
            candidateWidths.Add(GiulianiWidth);

            candidateHeights = new ObservableCollection<SplineDoubleKeyFrame>();
            candidateHeights.Add(McCainHeight);
            candidateHeights.Add(RichardsonHeight);
            candidateHeights.Add(KucinichHeight);
            candidateHeights.Add(GravelHeight);
            candidateHeights.Add(EdwardsHeight);
            candidateHeights.Add(DoddHeight);
            candidateHeights.Add(ClintonHeight);
            candidateHeights.Add(BidenHeight);
            candidateHeights.Add(ObamaHeight);
            candidateHeights.Add(ThompsonHeight);
            candidateHeights.Add(RomneyHeight);
            candidateHeights.Add(PaulHeight);
            candidateHeights.Add(HunterHeight);
            candidateHeights.Add(HuckabeeHeight);
            candidateHeights.Add(GiulianiHeight);


        }

        private void updateCircleValues(object sender, RoutedEventArgs e)
        {
            object something = (object)e.OriginalSource;
            if (dataGathered)
            {
                Slider thisTimeline = (Slider)sender;
                int timelineValueInt = Convert.ToInt32(thisTimeline.Value);

                if (timelineValueInt != lastTimelineValue)
                {
                    updateAllData(timelineValueInt);
                }

                lastTimelineValue = timelineValueInt;
            }
        }

        private void PlayAnim(object sender, RoutedEventArgs e)
        {
            if (Timeline.Value == 104)
            {
                Timeline.Value = 0;
            }
            
            if (Timeline.Value != 0)
            {
                int tInSeconds = Convert.ToInt32((Timeline.Value / Timeline.Maximum) * 40);
                TimelineStoryboard.Begin();
                TimelineStoryboard.Seek(new TimeSpan(0, 0, tInSeconds));
                PlayBtn.Visibility = Visibility.Collapsed;

            }
            else
            {
                TimelineStoryboard.Begin();
                PlayBtn.Visibility = Visibility.Collapsed;
            }
            
            
        }

        private void StopAnim(object sender, RoutedEventArgs e)
        {
            TimelineStoryboard.Pause();
            PlayBtn.Visibility = Visibility.Visible;
        }

        private void CloseAbout(object sender, RoutedEventArgs e)
        {
            CloseAboutAni.Begin();
        }

        private void OpenAbout(object sender, RoutedEventArgs e)
        {
            OpenAboutAni.Begin();
        }

        private void open6(object sender, MouseEventArgs e)
        {
            _6Entrance.Begin();
        }

        private void open9(object sender, MouseEventArgs e)
        {
            _9Entrance.Begin();
        }

        private void open12(object sender, MouseEventArgs e)
        {
            _12Entrance.Begin();
        }

        private void open23(object sender, MouseEventArgs e)
        {
            _23Entrance.Begin();
        }

        private void open59(object sender, MouseEventArgs e)
        {
            _54Entrance.Begin();
        }

        private void open64(object sender, MouseEventArgs e)
        {
            _64Entrance.Begin();
        }

        private void open68(object sender, MouseEventArgs e)
        {
            _68Entrance.Begin();
        }

        private void open81(object sender, MouseEventArgs e)
        {
            _81Entrance.Begin();
        }

        private void open93(object sender, MouseEventArgs e)
        {
            _93Entrance.Begin();
        }

        private void open94(object sender, MouseEventArgs e)
        {
            _94Entrance.Begin();
        }


	}
}